@@ -19,16 +19,18 @@ OC.L10N.register(
     "Change name" : "เปลี่ยนชื่อ",
     "Email address" : "ที่อยู่อีเมล",
     "Cancel" : "ยกเลิก",
-    "Accounts" : "บัญชี",
     "General" : "ทั่วไป",
-    "Register" : "ลงทะเบียน",
-    "About" : "เกี่ยวกับ",
-    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "Appearance" : "ลักษณะที่ปรากฏ",
+    "Newest first" : "ใหม่ที่สุดก่อน",
+    "Oldest first" : "เก่าที่สุดก่อน",
+    "Privacy" : "ความเป็นส่วนตัว",
+    "Security" : "ความปลอดภัย",
     "Archive" : "ที่เก็บถาวร",
     "Delete" : "ลบ",
     "Search" : "ค้นหา",
     "Send" : "ส่ง",
     "Refresh" : "รีเฟรช",
+    "About" : "เกี่ยวกับ",
     "Ok" : "ตกลง",
     "Choose" : "เลือก",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
@@ -37,6 +39,7 @@ OC.L10N.register(
     "Read" : "อ่าน",
     "Edit tags" : "แก้ไขแท็ก",
     "Back" : "ย้อนกลับ",
+    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
     "Description" : "คำอธิบาย",
     "Create" : "สร้าง",
     "Select" : "เลือก",
@@ -49,6 +52,7 @@ OC.L10N.register(
     "Last week" : "สัปดาห์ที่แล้ว",
     "Last month" : "เดือนที่แล้ว",
     "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
+    "Favorites" : "รายการโปรด",
     "Other" : "อื่น ๆ",
     "Forward" : "ส่งต่อ",
     "Translate" : "แปลภาษา",
@@ -71,11 +75,15 @@ OC.L10N.register(
     "Close" : "ปิด",
     "Date" : "วันที่",
     "Tags" : "แท็ก",
-    "Last 7 days" : "ภายใน 7 วัน",
     "Custom" : "กำหนดเอง",
     "Tag already exists" : "มีแท็กอยู่แล้ว",
     "Not found" : "ไม่พบ",
+    "Deleted" : "ลบแล้ว",
+    "Help" : "ช่วยเหลือ",
+    "Actions" : "การกระทำ",
     "Priority" : "ลำดับความสำคัญ",
+    "delete" : "ลบ",
+    "Edit" : "แก้ไข",
     "Reset" : "รีเซ็ต",
     "Client ID" : "รหัสไคลเอ็นต์",
     "Client secret" : "ข้อมูลลับไคลเอ็นต์",
@@ -91,7 +99,6 @@ OC.L10N.register(
     "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
     "Drafts" : "ฉบับร่าง",
-    "Favorites" : "รายการโปรด",
     "All inboxes" : "กล่องขาเข้าทั้งหมด",
     "Inbox" : "กล่องขาเข้า",
     "Junk" : "อีเมลขยะ",
@@ -102,6 +109,6 @@ OC.L10N.register(
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
     "Continue to %s" : "ดำเนินการต่อไปที่ %s",
-    "Actions" : "การกระทำ"
+    "Last 7 days" : "ภายใน 7 วัน"
 },
 "nplurals=1; plural=0;");
